pub struct ConsensusFlags(/* private fields */);Expand description
Full flag set for CLVM execution and consensus (condition parsing, validation, generator mode). Combines flags from clvmr (lower bytes) and consensus (upper bytes). The end goal should be to make these flags independent, but we still have at least one quirk in chia-protocol’s Program::run_rust() where it would be ideal to take Consensusflags, but it can’t depend on chia-consensus, so it has to take ClvmFlags instead. those aren’t exposed to python, so it relies on these flags matching.
Implementations
Sourceimpl ConsensusFlags
impl ConsensusFlags
pub const CANONICAL_INTS: Self
pub const NO_UNKNOWN_OPS: Self
pub const LIMIT_HEAP: Self
pub const RELAXED_BLS: Self
pub const ENABLE_KECCAK_OPS_OUTSIDE_GUARD: Self
pub const DISABLE_OP: Self
pub const ENABLE_SHA256_TREE: Self
pub const ENABLE_SECP_OPS: Self
Sourcepub const DONT_VALIDATE_SIGNATURE: Self
pub const DONT_VALIDATE_SIGNATURE: Self
Skip validating AGG_SIG / condition signatures.
Sourcepub const NO_UNKNOWN_CONDS: Self
pub const NO_UNKNOWN_CONDS: Self
Unknown condition codes are disallowed (mempool-mode).
Sourcepub const COMPUTE_FINGERPRINT: Self
pub const COMPUTE_FINGERPRINT: Self
Compute condition fingerprints for spends eligible for dedup.
Sourcepub const STRICT_ARGS_COUNT: Self
pub const STRICT_ARGS_COUNT: Self
Conditions require the exact supported argument count (mempool-mode).
Sourcepub const COST_CONDITIONS: Self
pub const COST_CONDITIONS: Self
Add flat cost to conditions (active after hard fork 2).
Sourcepub const SIMPLE_GENERATOR: Self
pub const SIMPLE_GENERATOR: Self
Simpler generator rules (hard fork behavior).
Sourceimpl ConsensusFlags
impl ConsensusFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ConsensusFlags
impl ConsensusFlags
Sourcepub const fn iter(&self) -> Iter<ConsensusFlags>
pub const fn iter(&self) -> Iter<ConsensusFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ConsensusFlags>
pub const fn iter_names(&self) -> IterNames<ConsensusFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl ConsensusFlags
impl ConsensusFlags
Sourcepub fn to_clvm_flags(self) -> ClvmFlags
pub fn to_clvm_flags(self) -> ClvmFlags
Convert to clvmr’s ClvmFlags by mapping each shared flag to its ClvmFlags counterpart. Does not rely on underlying bits being the same; consensus-only flags are ignored.